"use strict";

exports.__esModule = true;
exports.colorStyle = exports.textStyle = exports.buttonStyle = exports.left = exports.bottom = exports.right = exports.top = exports.zIndex = exports.position = exports.backgroundRepeat = exports.backgroundPosition = exports.backgroundSize = exports.backgroundImage = exports.background = exports.overflow = exports.opacity = exports.boxShadow = exports.borders = exports.borderRadius = exports.borderLeft = exports.borderBottom = exports.borderRight = exports.borderTop = exports.borderColor = exports.borderStyle = exports.borderWidth = exports.border = exports.gridArea = exports.gridTemplateAreas = exports.gridTemplateRows = exports.gridTemplateColumns = exports.gridAutoRows = exports.gridAutoColumns = exports.gridAutoFlow = exports.gridRow = exports.gridColumn = exports.gridRowGap = exports.gridColumnGap = exports.gridGap = exports.order = exports.alignSelf = exports.justifySelf = exports.flex = exports.flexDirection = exports.flexBasis = exports.flexWrap = exports.justifyContent = exports.justifyItems = exports.alignContent = exports.alignItems = exports.verticalAlign = exports.size = exports.minHeight = exports.maxHeight = exports.height = exports.minWidth = exports.maxWidth = exports.display = exports.letterSpacing = exports.fontStyle = exports.textAlign = exports.lineHeight = exports.fontWeight = exports.fontFamily = exports.fontSize = exports.width = exports.color = exports.backgroundColor = exports.textColor = exports.space = exports.paddingY = exports.paddingX = exports.paddingRight = exports.paddingLeft = exports.paddingBottom = exports.paddingTop = exports.padding = exports.marginY = exports.marginX = exports.marginRight = exports.marginLeft = exports.marginBottom = exports.marginTop = exports.margin = void 0;

var _core = require("./core");

var _shim = require("./shim");

var _variant = require("./variant");

var defaults = {
  space: [0, 4, 8, 16, 32, 64, 128, 256, 512],
  fontSizes: [12, 14, 16, 20, 24, 32, 48, 64, 72]
};

var isNumber = function isNumber(n) {
  return typeof n === 'number' && !isNaN(n);
}; // space


var getMargin = function getMargin(n, scale) {
  if (!isNumber(n)) {
    return (0, _core.get)(scale, n, n);
  }

  var isNegative = n < 0;
  var absolute = Math.abs(n);
  var value = (0, _core.get)(scale, absolute);

  if (!isNumber(value)) {
    return isNegative ? '-' + value : value;
  }

  return value * (isNegative ? -1 : 1);
};

var margin = (0, _shim.style)({
  prop: 'margin',
  alias: 'm',
  key: 'space',
  transformValue: getMargin,
  scale: defaults.space
});
exports.margin = margin;
var marginTop = (0, _shim.style)({
  prop: 'marginTop',
  alias: 'mt',
  key: 'space',
  transformValue: getMargin,
  scale: defaults.space
});
exports.marginTop = marginTop;
var marginBottom = (0, _shim.style)({
  prop: 'marginBottom',
  alias: 'mb',
  key: 'space',
  transformValue: getMargin,
  scale: defaults.space
});
exports.marginBottom = marginBottom;
var marginLeft = (0, _shim.style)({
  prop: 'marginLeft',
  alias: 'ml',
  key: 'space',
  transformValue: getMargin,
  scale: defaults.space
});
exports.marginLeft = marginLeft;
var marginRight = (0, _shim.style)({
  prop: 'marginRight',
  alias: 'mr',
  key: 'space',
  transformValue: getMargin,
  scale: defaults.space
});
exports.marginRight = marginRight;
var marginX = (0, _shim.style)({
  prop: 'marginX',
  properties: ['marginLeft', 'marginRight'],
  alias: 'mx',
  key: 'space',
  transformValue: getMargin,
  scale: defaults.space
});
exports.marginX = marginX;
var marginY = (0, _shim.style)({
  prop: 'marginY',
  properties: ['marginTop', 'marginBottom'],
  alias: 'my',
  key: 'space',
  transformValue: getMargin,
  scale: defaults.space
});
exports.marginY = marginY;
var padding = (0, _shim.style)({
  prop: 'padding',
  alias: 'p',
  key: 'space',
  scale: defaults.space
});
exports.padding = padding;
var paddingTop = (0, _shim.style)({
  prop: 'paddingTop',
  alias: 'pt',
  key: 'space',
  scale: defaults.space
});
exports.paddingTop = paddingTop;
var paddingBottom = (0, _shim.style)({
  prop: 'paddingBottom',
  alias: 'pb',
  key: 'space',
  scale: defaults.space
});
exports.paddingBottom = paddingBottom;
var paddingLeft = (0, _shim.style)({
  prop: 'paddingLeft',
  alias: 'pl',
  key: 'space',
  scale: defaults.space
});
exports.paddingLeft = paddingLeft;
var paddingRight = (0, _shim.style)({
  prop: 'paddingRight',
  alias: 'pr',
  key: 'space',
  scale: defaults.space
});
exports.paddingRight = paddingRight;
var paddingX = (0, _shim.style)({
  prop: 'paddingX',
  properties: ['paddingLeft', 'paddingRight'],
  alias: 'px',
  key: 'space',
  scale: defaults.space
});
exports.paddingX = paddingX;
var paddingY = (0, _shim.style)({
  prop: 'paddingY',
  properties: ['paddingTop', 'paddingBottom'],
  alias: 'py',
  key: 'space',
  scale: defaults.space
});
exports.paddingY = paddingY;
var space = (0, _shim.compose)(margin, marginTop, marginBottom, marginLeft, marginRight, marginX, marginY, padding, paddingTop, paddingBottom, paddingLeft, paddingRight, paddingX, paddingY); // color

exports.space = space;
var textColor = (0, _shim.style)({
  prop: 'color',
  key: 'colors'
});
exports.textColor = textColor;
var backgroundColor = (0, _shim.style)({
  prop: 'backgroundColor',
  alias: 'bg',
  key: 'colors'
});
exports.backgroundColor = backgroundColor;
var color = (0, _shim.compose)(textColor, backgroundColor); // width

exports.color = color;

var getWidth = function getWidth(n, scale) {
  return !isNumber(n) || n > 1 ? n : n * 100 + '%';
};

var width = (0, _shim.style)({
  prop: 'width',
  key: 'widths',
  transformValue: getWidth
}); // typography

exports.width = width;
var fontSize = (0, _shim.style)({
  prop: 'fontSize',
  key: 'fontSizes',
  scale: defaults.fontSizes
});
exports.fontSize = fontSize;
var fontFamily = (0, _shim.style)({
  prop: 'fontFamily',
  key: 'fonts'
});
exports.fontFamily = fontFamily;
var fontWeight = (0, _shim.style)({
  prop: 'fontWeight',
  key: 'fontWeights'
});
exports.fontWeight = fontWeight;
var lineHeight = (0, _shim.style)({
  prop: 'lineHeight',
  key: 'lineHeights'
});
exports.lineHeight = lineHeight;
var textAlign = (0, _shim.style)({
  prop: 'textAlign'
});
exports.textAlign = textAlign;
var fontStyle = (0, _shim.style)({
  prop: 'fontStyle'
});
exports.fontStyle = fontStyle;
var letterSpacing = (0, _shim.style)({
  prop: 'letterSpacing',
  key: 'letterSpacings'
}); // layout

exports.letterSpacing = letterSpacing;
var display = (0, _shim.style)({
  prop: 'display'
});
exports.display = display;
var maxWidth = (0, _shim.style)({
  prop: 'maxWidth',
  key: 'maxWidths'
});
exports.maxWidth = maxWidth;
var minWidth = (0, _shim.style)({
  prop: 'minWidth',
  key: 'minWidths'
});
exports.minWidth = minWidth;
var height = (0, _shim.style)({
  prop: 'height',
  key: 'heights'
});
exports.height = height;
var maxHeight = (0, _shim.style)({
  prop: 'maxHeight',
  key: 'maxHeights'
});
exports.maxHeight = maxHeight;
var minHeight = (0, _shim.style)({
  prop: 'minHeight',
  key: 'minHeights'
});
exports.minHeight = minHeight;
var size = (0, _shim.style)({
  prop: 'size',
  properties: ['width', 'height'],
  key: 'sizes'
});
exports.size = size;
var verticalAlign = (0, _shim.style)({
  prop: 'verticalAlign'
}); // flexbox

exports.verticalAlign = verticalAlign;
var alignItems = (0, _shim.style)({
  prop: 'alignItems'
});
exports.alignItems = alignItems;
var alignContent = (0, _shim.style)({
  prop: 'alignContent'
});
exports.alignContent = alignContent;
var justifyItems = (0, _shim.style)({
  prop: 'justifyItems'
});
exports.justifyItems = justifyItems;
var justifyContent = (0, _shim.style)({
  prop: 'justifyContent'
});
exports.justifyContent = justifyContent;
var flexWrap = (0, _shim.style)({
  prop: 'flexWrap'
});
exports.flexWrap = flexWrap;
var flexBasis = (0, _shim.style)({
  prop: 'flexBasis',
  transformValue: getWidth
});
exports.flexBasis = flexBasis;
var flexDirection = (0, _shim.style)({
  prop: 'flexDirection'
});
exports.flexDirection = flexDirection;
var flex = (0, _shim.style)({
  prop: 'flex'
});
exports.flex = flex;
var justifySelf = (0, _shim.style)({
  prop: 'justifySelf'
});
exports.justifySelf = justifySelf;
var alignSelf = (0, _shim.style)({
  prop: 'alignSelf'
});
exports.alignSelf = alignSelf;
var order = (0, _shim.style)({
  prop: 'order'
}); // grid

exports.order = order;
var gridGap = (0, _shim.style)({
  prop: 'gridGap',
  key: 'space',
  scale: defaults.space
});
exports.gridGap = gridGap;
var gridColumnGap = (0, _shim.style)({
  prop: 'gridColumnGap',
  key: 'space',
  scale: defaults.space
});
exports.gridColumnGap = gridColumnGap;
var gridRowGap = (0, _shim.style)({
  prop: 'gridRowGap',
  key: 'space',
  scale: defaults.space
});
exports.gridRowGap = gridRowGap;
var gridColumn = (0, _shim.style)({
  prop: 'gridColumn'
});
exports.gridColumn = gridColumn;
var gridRow = (0, _shim.style)({
  prop: 'gridRow'
});
exports.gridRow = gridRow;
var gridAutoFlow = (0, _shim.style)({
  prop: 'gridAutoFlow'
});
exports.gridAutoFlow = gridAutoFlow;
var gridAutoColumns = (0, _shim.style)({
  prop: 'gridAutoColumns'
});
exports.gridAutoColumns = gridAutoColumns;
var gridAutoRows = (0, _shim.style)({
  prop: 'gridAutoRows'
});
exports.gridAutoRows = gridAutoRows;
var gridTemplateColumns = (0, _shim.style)({
  prop: 'gridTemplateColumns'
});
exports.gridTemplateColumns = gridTemplateColumns;
var gridTemplateRows = (0, _shim.style)({
  prop: 'gridTemplateRows'
});
exports.gridTemplateRows = gridTemplateRows;
var gridTemplateAreas = (0, _shim.style)({
  prop: 'gridTemplateAreas'
});
exports.gridTemplateAreas = gridTemplateAreas;
var gridArea = (0, _shim.style)({
  prop: 'gridArea'
}); // borders

exports.gridArea = gridArea;
var border = (0, _shim.style)({
  prop: 'border',
  key: 'borders'
});
exports.border = border;
var borderWidth = (0, _shim.style)({
  prop: 'borderWidth',
  key: 'borderWidths'
});
exports.borderWidth = borderWidth;
var borderStyle = (0, _shim.style)({
  prop: 'borderStyle',
  key: 'borderStyles'
});
exports.borderStyle = borderStyle;
var borderColor = (0, _shim.style)({
  prop: 'borderColor',
  key: 'colors'
});
exports.borderColor = borderColor;
var borderTop = (0, _shim.style)({
  prop: 'borderTop',
  key: 'borders'
});
exports.borderTop = borderTop;
var borderRight = (0, _shim.style)({
  prop: 'borderRight',
  key: 'borders'
});
exports.borderRight = borderRight;
var borderBottom = (0, _shim.style)({
  prop: 'borderBottom',
  key: 'borders'
});
exports.borderBottom = borderBottom;
var borderLeft = (0, _shim.style)({
  prop: 'borderLeft',
  key: 'borders'
});
exports.borderLeft = borderLeft;
var borderRadius = (0, _shim.style)({
  prop: 'borderRadius',
  key: 'radii'
});
exports.borderRadius = borderRadius;
var borders = (0, _shim.compose)(border, borderTop, borderRight, borderBottom, borderLeft, borderWidth, borderStyle, borderColor, borderRadius);
exports.borders = borders;
var boxShadow = (0, _shim.style)({
  prop: 'boxShadow',
  key: 'shadows'
});
exports.boxShadow = boxShadow;
var opacity = (0, _shim.style)({
  prop: 'opacity'
});
exports.opacity = opacity;
var overflow = (0, _shim.style)({
  prop: 'overflow'
}); // backgrounds

exports.overflow = overflow;
var background = (0, _shim.style)({
  prop: 'background'
});
exports.background = background;
var backgroundImage = (0, _shim.style)({
  prop: 'backgroundImage'
});
exports.backgroundImage = backgroundImage;
var backgroundSize = (0, _shim.style)({
  prop: 'backgroundSize'
});
exports.backgroundSize = backgroundSize;
var backgroundPosition = (0, _shim.style)({
  prop: 'backgroundPosition'
});
exports.backgroundPosition = backgroundPosition;
var backgroundRepeat = (0, _shim.style)({
  prop: 'backgroundRepeat'
}); // position

exports.backgroundRepeat = backgroundRepeat;
var position = (0, _shim.style)({
  prop: 'position'
});
exports.position = position;
var zIndex = (0, _shim.style)({
  prop: 'zIndex',
  key: 'zIndices'
});
exports.zIndex = zIndex;
var top = (0, _shim.style)({
  prop: 'top'
});
exports.top = top;
var right = (0, _shim.style)({
  prop: 'right'
});
exports.right = right;
var bottom = (0, _shim.style)({
  prop: 'bottom'
});
exports.bottom = bottom;
var left = (0, _shim.style)({
  prop: 'left'
}); // variants

exports.left = left;
var buttonStyle = (0, _variant.variant)({
  key: 'buttons'
});
exports.buttonStyle = buttonStyle;
var textStyle = (0, _variant.variant)({
  key: 'textStyles',
  prop: 'textStyle'
});
exports.textStyle = textStyle;
var colorStyle = (0, _variant.variant)({
  key: 'colorStyles',
  prop: 'colors'
});
exports.colorStyle = colorStyle;